@@ -1,12 +1,14 @@
 # -*- coding: utf-8 -*-
 import logging
+from typing import Optional
 
 logging.basicConfig()
 
 dtslogger = logging.getLogger("dts")
 dtslogger.setLevel(logging.INFO)
 
-__version__ = "5.2.7"
+__version__ = "5.4.5"
+
 
 dtslogger.debug(f"duckietown-shell {__version__}")
 
@@ -20,12 +22,15 @@ if sys.version_info < (3, 6):
 from .exceptions import ConfigInvalid, ConfigNotPresent
 from .utils import format_exception
 
-import locale
-
-dtslogger.debug(
-    f"encoding: stdout {sys.stdout.encoding} stderr {sys.stderr.encoding} "
-    f"locale {locale.getpreferredencoding()}."
-)
+# This was useful in the days of Python 2. Removing because it breaks when the shell is called
+# using pipes (e.g. unit tests).
+#
+# import locale
+#
+# dtslogger.debug(
+#     f"encoding: stdout {sys.stdout.encoding} stderr {sys.stderr.encoding} "
+#     f"locale {locale.getpreferredencoding()}."
+# )
 
 from .cli import DTShell
 from .logging import dts_print
@@ -37,3 +42,7 @@ from .exceptions import *
 
 from .main import OtherVersions
 from .package_version_check import *
+
+
+# singleton
+shell: Optional[DTShell] = None
