@@ -5,6 +5,7 @@ import re
 import sys
 from typing import Dict, Union
 
+import dt_shell
 import yaml
 
 from . import __version__, dtslogger
@@ -22,6 +23,7 @@ from .exceptions import (
 )
 from .logging import dts_print
 from .utils import format_exception, href, replace_spaces
+from .package_version_check import _get_installed_distributions
 
 
 class OtherVersions:
@@ -77,24 +79,25 @@ def print_version_info() -> None:
     }
 
     try:
-        # noinspection PyCompatibility,PyUnresolvedReferences
-        from pip._internal.utils.misc import get_installed_distributions
-    except ImportError:
-        dtslogger.warning('Please update "pip" to have better debug info.')
-    else:
-        installed = get_installed_distributions()
+        installed = _get_installed_distributions()
         pkgs = {_.project_name: _.version for _ in installed}
         for pkg_name, pkg_version in pkgs.items():
-            include = ('duckietown' in pkg_name) or ('dt-' in pkg_name) or ('-z' in pkg_name) or (
-                    'aido' in pkg_name)
+            include = (
+                ("duckietown" in pkg_name)
+                or ("dt-" in pkg_name)
+                or ("-z" in pkg_name)
+                or ("aido" in pkg_name)
+            )
             if include:
                 v[pkg_name] = pkg_version
+    except ImportError:
+        dtslogger.warning('Please update "pip" to have better debug info.')
 
     versions = yaml.dump(v, default_flow_style=False)
     # Please = termcolor.colored('Please', 'red', attrs=['bold'])
-    fn = '~/shell-debug-info.txt'
+    fn = "~/shell-debug-info.txt"
     fn = os.path.expanduser(fn)
-    with open(fn, 'w') as f:
+    with open(fn, "w") as f:
         f.write(versions)
     msg = f"""\
 To report a bug, please also include the contents of {fn}
@@ -189,6 +192,9 @@ def cli_main_() -> None:
 
     shell = DTShell(shell_config, commands_info)
 
+    # populate singleton
+    dt_shell.shell = shell
+
     if arguments:
         arguments = map(replace_spaces, arguments)
         cmdline = " ".join(arguments)
