@@ -1,7 +1,8 @@
+import subprocess
 import traceback
 from typing import Optional
+
 import termcolor
-import subprocess
 
 from . import dtslogger
 
@@ -28,13 +29,13 @@ def indent(s: str, prefix: str, first: Optional[str] = None) -> str:
 
 
 def raise_wrapped(etype, e, msg, compact=False, exc=None, **kwargs):
-    """ Raises an exception of type etype by wrapping
-        another exception "e" with its backtrace and adding
-        the objects in kwargs as formatted by format_obs.
+    """Raises an exception of type etype by wrapping
+    another exception "e" with its backtrace and adding
+    the objects in kwargs as formatted by format_obs.
 
-        if compact = False, write the whole traceback, otherwise just str(e).
+    if compact = False, write the whole traceback, otherwise just str(e).
 
-        exc = output of sys.exc_info()
+    exc = output of sys.exc_info()
     """
 
     e = raise_wrapped_make(etype, e, msg, compact=compact, **kwargs)
@@ -47,7 +48,7 @@ def raise_wrapped(etype, e, msg, compact=False, exc=None, **kwargs):
 
 
 def raise_wrapped_make(etype, e, msg, compact=False, **kwargs):
-    """ Constructs the exception to be thrown by raise_wrapped() """
+    """Constructs the exception to be thrown by raise_wrapped()"""
     assert isinstance(e, BaseException), type(e)
     assert isinstance(msg, str), type(msg)
     s = msg
@@ -74,7 +75,7 @@ def check_isinstance(ob, expected, **kwargs):
 
 
 def raise_type_mismatch(ob, expected, **kwargs):
-    """ Raises an exception concerning ob having the wrong type. """
+    """Raises an exception concerning ob having the wrong type."""
     e = "Object not of expected type:"
     e += "\n  expected: %s" % str(expected)
     e += "\n  obtained: %s" % str(type(ob))
@@ -98,11 +99,11 @@ def format_exception(e):
 
 
 def href(x):
-    return termcolor.colored(x, "blue", attrs=["underline"])
+    return termcolor.colored(x, "blue", None, ["underline"])
 
 
 def dark_yellow(x):
-    return termcolor.colored(x, "yellow", attrs=[])
+    return termcolor.colored(x, "yellow")
 
 
 def dark(x):
